# protein

This simple package allows for the searching of one or several UniProt accession numbers in the command line. The default output contains the full protein name, organism of origin, gene that codes for the protein, and the amino acid sequence. Other output formats include multiline FASTA and one-line FASTA.  

## Installation

Run `pip install protein` in the terminal. 

## Usage

To run: `protein [id number 1] [id number 2] [id number 3]...`

Options: 

`-s, --sequence`: output only the amino acid sequence

`-n, --name`: output only the protein's full name

`-g, --gene`: ouptut only the gene that codes for the protein

`-o, --organism`: output only the organism of origin

`-f, --fasta`: ouput a multi-line FASTA (from UniProt)

`-l, --oneline`: output a one-line FASTA

## Examples

Input: `protein P0DTC3`

Output: 

```
***Protein P0DTC3***


Name: Protein 3a


Organism: Severe acute respiratory syndrome coronavirus 2


Gene: 3a


Amino acid sequence: MDLFMRIFTIGTVTLKQGEIKDATPSDFVRATATIPIQASLPFGWLIVGVALLAVFQSASKIITLKKRWQLALSKGVHFVCNLLLLFVTVYSHLLLVAAGLEAPFLYLYALVYFLQSINFVRIIMRLWLCWKCRSKNPLLYDANYFLCWHTNCYDYCIPYNSVTSSIVITSGDGTTSPISEHDYQIGGYTEKWESGVKDCVVLHSYFTSDYYQLYSTQLSTDTGVEHVTFFIYNKIVDEPEEHVQIHTIDGSSGVVNPVMEPIYDEPTTTTSVPL




***Protein P59594***


Name: Spike glycoprotein


Organism: Human SARS coronavirus


Gene: S


Amino acid sequence:  
```


<br>


Input: `protein P0DTC3 -s`

Output:

```
MDLFMRIFTIGTVTLKQGEIKDATPSDFVRATATIPIQASLPFGWLIVGVALLAVFQSASKIITLKKRWQLALSKGVHFVCNLLLLFVTVYSHLLLVAAGLEAPFLYLYALVYFLQSINFVRIIMRLWLCWKCRSKNPLLYDANYFLCWHTNCYDYCIPYNSVTSSIVITSGDGTTSPISEHDYQIGGYTEKWESGVKDCVVLHSYFTSDYYQLYSTQLSTDTGVEHVTFFIYNKIVDEPEEHVQIHTIDGSSGVVNPVMEPIYDEPTTTTSVPL
```

<br>

Input: `protein P0DTC3 P59594 -o`

Output: 

```
Severe acute respiratory syndrome coronavirus 2
Human SARS coronavirus
```

<br>

Input: `protein P0DTC3 P59594 -f`

Output: 

```
>sp|P0DTC3|AP3A_SARS2 Protein 3a OS=Severe acute respiratory syndrome coronavirus 2 OX=2697049 GN=3a PE=3 SV=1
MDLFMRIFTIGTVTLKQGEIKDATPSDFVRATATIPIQASLPFGWLIVGVALLAVFQSAS
KIITLKKRWQLALSKGVHFVCNLLLLFVTVYSHLLLVAAGLEAPFLYLYALVYFLQSINF
VRIIMRLWLCWKCRSKNPLLYDANYFLCWHTNCYDYCIPYNSVTSSIVITSGDGTTSPIS
EHDYQIGGYTEKWESGVKDCVVLHSYFTSDYYQLYSTQLSTDTGVEHVTFFIYNKIVDEP
EEHVQIHTIDGSSGVVNPVMEPIYDEPTTTTSVPL
>sp|P59594|SPIKE_CVHSA Spike glycoprotein OS=Human SARS coronavirus OX=694009 GN=S PE=1 SV=1

GFIAGLIAIVMVTILLCCMTSCCSCLKGACSCGSCCKFDEDDSEPVLKGVKLHYT
```
